@@ -14,11 +14,14 @@ class DevDeck:
 
     def set_active_deck(self, deck):
         self.__logger.info("Setting active deck: %s", type(deck).__name__)
-        [d.clear_deck_context() for d in self.decks]
+        for deck_itr in self.decks:
+            deck_itr.clear_deck_context()
         self.decks.append(deck)
         self.get_active_deck().render(DeckContext(self, self.__deck))
 
     def get_active_deck(self):
+        if not self.decks:
+            return None
         return self.decks[-1]
 
     def pop_active_deck(self):
@@ -34,3 +37,10 @@ class DevDeck:
             self.get_active_deck().pressed(key)
         else:
             self.get_active_deck().released(key)
+
+    def close(self):
+        keys = self.__deck.key_count()
+        for deck in self.decks:
+            deck.dispose()
+        for key_no in range(keys):
+            self.__deck.set_key_image(key_no, None)
\ No newline at end of file
